@@ -37,6 +37,8 @@ def it_streaming(i: ItemUrlFilter):
     print('001')
     yield write_csv_header_to_gz(i)
     print('002')
+    print(i)
+    print('002.1')
     for int_progress, bytes1 in it_chunk(
             i.lst_url, i.target_directory, i.lst_distinct_column, i.lst_column_match, i.sort_column):
         print('003')
@@ -80,5 +82,5 @@ def streaming_get(md5_hex):
     return StreamingResponse(it_streaming(dic_item_url_filter[md5_hex]), headers=dic)
 
 
-def server(host='0.0.0.0', int_port=20410):
+def server(host='0.0.0.0', int_port=20413):
     uvicorn.run("cameo_claw.streaming:app", host=host, port=int_port, reload=False, debug=False, workers=1)
